pub trait PluginOptionsDeserializer<T: DeserializeOwned>: Send + Sync {
// Required method
fn deserialize(&self, payload: &str) -> Result<T, Error>;
}Expand description
A trait for deserializing Metasrv config from a JSON string.
pub trait PluginOptionsDeserializer<T: DeserializeOwned>: Send + Sync {
// Required method
fn deserialize(&self, payload: &str) -> Result<T, Error>;
}A trait for deserializing Metasrv config from a JSON string.