pub fn record_dropped_plugin(tag: &str)
Records a plugin option tag that was dropped because it is not recognized by this build (for example, an enterprise plugin option seen by an open-source build).